@@ -36,7 +36,11 @@ ansi_dialect = load_raw_dialect("ansi")
 trino_dialect = ansi_dialect.copy_as(
     "trino",
     formatted_name="Trino",
-    docstring="""**Default Casing**: ``UPPERCASE``
+    docstring="""**Default Casing**: ``lowercase``, although the case
+of a reference is used in the result set column label. If a column is defined
+using :code:`CREATE TEMPORARY TABLE foo (COL1 int)`, then :code:`SELECT * FROM foo`
+returns a column labelled :code:`col1`, however :code:`SELECT COL1 FROM foo`
+returns a column labelled :code:`COL1`.
 
 **Quotes**: String Literals: ``''``, Identifiers: ``""``
 
@@ -74,6 +78,11 @@ trino_dialect.add(
         "<", SymbolSegment, type="start_angle_bracket"
     ),
     EndAngleBracketSegment=StringParser(">", SymbolSegment, type="end_angle_bracket"),
+    FormatJsonEncodingGrammar=Sequence(
+        "FORMAT",
+        "JSON",
+        Sequence("ENCODING", OneOf("UTF8", "UTF16", "UTF32"), optional=True),
+    ),
 )
 
 trino_dialect.bracket_sets("angle_bracket_pairs").update(
@@ -218,6 +227,24 @@ trino_dialect.replace(
                 Ref("ColumnReferenceSegment"),
             ),
         ),
+        # For JSON_QUERY function
+        # https://trino.io/docs/current/functions/json.html#json-query
+        Sequence(
+            Ref("ExpressionSegment"),  # json_input
+            Ref("FormatJsonEncodingGrammar", optional=True),
+            Ref("CommaSegment"),
+            Ref("ExpressionSegment"),  # json_path
+            OneOf(
+                Sequence("WITHOUT", Ref.keyword("ARRAY", optional=True), "WRAPPER"),
+                Sequence(
+                    "WITH",
+                    OneOf("CONDITIONAL", "UNCONDITIONAL", optional=True),
+                    Ref.keyword("ARRAY", optional=True),
+                    "WRAPPER",
+                ),
+                optional=True,
+            ),
+        ),
         Ref("IgnoreRespectNullsGrammar"),
         Ref("IndexColumnDefinitionSegment"),
         Ref("EmptyStructLiteralSegment"),
@@ -239,6 +266,7 @@ trino_dialect.replace(
         Ref("LambdaExpressionSegment"),
         Ref("ExpressionSegment"),
     ),
+    TemporaryTransientGrammar=Nothing(),
 )
 
 
@@ -275,11 +303,7 @@ class DatatypeSegment(BaseSegment):
         "JSON",
         # Date and time
         "DATE",
-        Sequence(
-            OneOf("TIME", "TIMESTAMP"),
-            Ref("BracketedArguments", optional=True),
-            Sequence(OneOf("WITH", "WITHOUT"), "TIME", "ZONE", optional=True),
-        ),
+        Ref("TimeWithTZGrammar"),
         # Structural
         Ref("ArrayTypeSegment"),
         "MAP",
